<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Line</name>
    <message>
        <location filename="../Line.js" line="+81"/>
        <source>Line Tools</source>
        <translation>Nástroje úsečky</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show line tools</source>
        <translation>Zobrazit nástroje úsečky</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Line</source>
        <translation>Ú&amp;sečka</translation>
    </message>
    <message>
        <location filename="../Line.ui" line="+17"/>
        <source>Same Entity Type as Original</source>
        <translation>Stejný typ objektu jako originál</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Line Segment</source>
        <translation>Segment úsečky</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Infinite Line</source>
        <translation>Nekonečná přímka</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Ray</source>
        <translation>Paprsek</translation>
    </message>
</context>
</TS>
